/** @jsxImportSource @emotion/react */
import React from 'react';
import { Theme } from "./Theme";
import { ToastContainer, ToastPosition } from 'react-toastify';
import { TypeOptions } from "react-toastify/dist/types";
import 'react-toastify/dist/ReactToastify.css';
interface RenderArgs {
    id: string | number;
    onClose: () => void;
}
interface Toast {
    position?: ToastPosition;
    duration?: number | null;
    title?: string;
    subtitle?: string;
    theme?: Theme;
    intent?: TypeOptions;
    render?: (options: RenderArgs) => React.ReactNode;
}
/** 类Hook的 需要用到jsx, css的场合,不同一般地Hook。
 * We export toast as a hook because it allows us to consume
 * the current theme context that it's in and pass that
 * onto our render function
 报错来源： ReactDOM.render is no longer supported in React 18. Use createRoot instead. Until you switch to the new API, your app will behave as if it's running React 17.
 【配套】 必须在APP顶级组件中 再配个<ToastContainer />才能生效。
 */
export declare function useToast(): ({ position, duration, render, title, subtitle, intent }: Toast) => import("react-toastify").Id;
export { ToastContainer };
